@@ -111,7 +111,6 @@ display_about_dialog (BonoboUIComponent *uic,
     };
 
     gtk_show_about_dialog (NULL,
-	"name",        _("Disk Mounter"),
 	"version",     VERSION,
 	"copyright",   "Copyright \xC2\xA9 2004 Canonical Ltd",
 	"comments",    _("Applet for mounting and unmounting block volumes."),
@@ -168,6 +167,8 @@ applet_factory (PanelApplet *applet,
     AtkObject *ao;
 
     if (!strcmp (iid, drivemount_iid)) {
+	g_set_application_name (_("Disk Mounter"));
+
 	gtk_window_set_default_icon_name ("media-floppy");
 
 	panel_applet_set_flags (applet, PANEL_APPLET_EXPAND_MINOR);
