@@ -57,7 +57,6 @@ struct _ModemAppletPrivate
   GtkIconTheme *icon_theme;
   GdkPixbuf    *icon;
   GtkWidget    *image;
-  GtkTooltips  *tooltips;
 
   /* auth dialog */
   GtkWidget    *auth_dialog;
@@ -150,32 +149,7 @@ static const BonoboUIVerb menu_verbs[] = {
   BONOBO_UI_VERB_END
 };
 
-static GType
-modem_applet_get_type (void)
-{
-  static GType type = 0;
-
-  if (!type)
-    {
-      static const GTypeInfo info =
-        {
-	  sizeof (ModemAppletClass),
-	  NULL,		/* base_init */
-	  NULL,		/* base_finalize */
-	  (GClassInitFunc) modem_applet_class_init,
-	  NULL,		/* class_finalize */
-	  NULL,		/* class_data */
-	  sizeof (ModemApplet),
-	  0,		/* n_preallocs */
-	  (GInstanceInitFunc) modem_applet_init,
-	};
-
-      type = g_type_register_static (PANEL_TYPE_APPLET, "ModemApplet",
-				     &info, 0);
-    }
-
-  return type;
-}
+G_DEFINE_TYPE (ModemApplet, modem_applet, PANEL_TYPE_APPLET)
 
 static void
 modem_applet_class_init (ModemAppletClass *class)
@@ -200,13 +174,14 @@ modem_applet_init (ModemApplet *applet)
   ModemAppletPrivate *priv;
   GdkPixbuf *pixbuf;
 
+  g_set_application_name ( _("Modem Monitor"));
+
   priv = MODEM_APPLET_GET_PRIVATE (applet);
 
   priv->xml = glade_xml_new (GNOME_GLADEDIR "/modemlights.glade", NULL, NULL);
   priv->icon = NULL;
   priv->icon_theme = gtk_icon_theme_get_default ();
   priv->image = gtk_image_new ();
-  priv->tooltips = gtk_tooltips_new ();
 
   priv->auth_dialog       = glade_xml_get_widget (priv->xml, "auth_dialog");
   priv->auth_dialog_label = glade_xml_get_widget (priv->xml, "auth_dialog_label");
@@ -219,7 +194,7 @@ modem_applet_init (ModemApplet *applet)
   g_signal_connect (G_OBJECT (priv->report_window), "delete-event",
 		    G_CALLBACK (gtk_widget_hide), NULL);
 
-  pixbuf = gtk_icon_theme_load_icon (priv->icon_theme, "gnome-modem", 48, 0, NULL);
+  pixbuf = gtk_icon_theme_load_icon (priv->icon_theme, "gnome-modem-monitor-applet", 48, 0, NULL);
   gtk_image_set_from_pixbuf (GTK_IMAGE (priv->report_window_image), pixbuf);
   gdk_pixbuf_unref (pixbuf);
 
@@ -750,8 +725,8 @@ update_tooltip (ModemApplet *applet)
   else
     text = g_strdup (_("Not connected"));
 
-  gtk_tooltips_set_tip(priv->tooltips, GTK_WIDGET (applet), text, NULL);
-  g_free(text);
+  gtk_widget_set_tooltip_text (GTK_WIDGET (applet), text);
+  g_free (text);
 
   return TRUE;
 }
@@ -1040,14 +1015,13 @@ on_modem_applet_about_clicked (BonoboUIComponent *uic,
   };
 */
   gtk_show_about_dialog (NULL,
-			 "name",               _("Modem Monitor"),
 			 "version",            VERSION,
 			 "copyright",          "Copyright \xC2\xA9 2004 Free Software Foundation. Inc.",
 			 "comments",           _("Applet for activating and monitoring a dial-up network connection."),
 			 "authors",            authors,
 			 /* "documenters",        documenters, */
 			 "translator-credits", _("translator-credits"),
-			 "logo_icon_name",     "gnome-modem",
+			 "logo_icon_name",     "gnome-modem-monitor-applet",
 			 NULL);
 }
 
